STANDARD_ENGINE_NAME: str = 'requests'
# FLAGS
HTTP_FLAG_METHOD: str = "method"
HTTP_FLAG_ENDPOINT: str = "endpoint"
HTTP_FLAG_HEADERS: str = "headers"
HTTP_FLAG_PARAMETERS: str = "parameters"
HTTP_FLAG_BODY: str = "body"

# HTTP COMMAND NAME
HTTP_COMMAND_NAME = "http"
